Learn R Programming

jacobi (version 3.1.1)

jtheta3: Jacobi theta function three

Description

Evaluates the third Jacobi theta function.

Usage

jtheta3(z, tau = NULL, q = NULL)

ljtheta3(z, tau = NULL, q = NULL)

Value

A complex number, vector or matrix; jtheta3 evaluates the third Jacobi theta function and ljtheta3 evaluates its logarithm.

Arguments

z

complex number, vector, or matrix

tau

lattice parameter, a complex number with strictly positive imaginary part; the two complex numbers tau and q are related by q = exp(1i*pi*tau), and only one of them must be supplied

q

the nome, a complex number whose modulus is strictly less than one, but not zero

Examples

Run this code
jtheta3(1 + 1i, q = exp(-pi/2))

Run the code above in your browser using DataLab