Learn R Programming

jacobi (version 3.1.1)

jtheta_ab: Jacobi theta function with characteristics

Description

Evaluates the Jacobi theta function with characteristics.

Usage

jtheta_ab(a, b, z, tau = NULL, q = NULL)

Value

A complex number, vector or matrix, like z.

Arguments

a, b

the characteristics, two complex numbers

z

complex number, vector, or matrix

tau

lattice parameter, a complex number with strictly positive imaginary part; the two complex numbers tau and q are related by q = exp(1i*pi*tau), and only one of them must be supplied

q

the nome, a complex number whose modulus is strictly less than one, but not zero

Details

The Jacobi theta function with characteristics generalizes the four Jacobi theta functions. It is denoted by 𝜃[a,b](z|τ). One gets the four Jacobi theta functions when a and b take the values 0 or 0.5:

if a=b=0.5

then one gets -𝜗1(z|τ)

if a=0.5 and b=0

then one gets 𝜗2(z|τ)

if a=b=0

then one gets 𝜗3(z|τ)

if a=0 and b=0.5

then one gets 𝜗4(z|τ)

Both 𝜃[a,b](z+π|τ) and 𝜃[a,b](z+π×τ|τ) are equal to 𝜃[a,b](z|τ) up to a factor - see the examples for the details.

References

Hershel M. Farkas, Irwin Kra. Theta Constants, Riemann Surfaces and the Modular Group: An Introduction with Applications to Uniformization Theorems, Partition Identities and Combinatorial Number Theory. Graduate Studies in Mathematics, volume 37, 2001.

Examples

Run this code
a   <- 2 + 0.3i
b   <- 1 - 0.6i
z   <- 0.1 + 0.4i
tau <- 0.2 + 0.3i
jab <- jtheta_ab(a, b, z, tau) 
# first property ####
jtheta_ab(a, b, z + pi, tau) # is equal to:
jab * exp(2i*pi*a)
# second property ####
jtheta_ab(a, b, z + pi*tau, tau) # is equal to:
jab * exp(-1i*(pi*tau + 2*z + 2*pi*b))

Run the code above in your browser using DataLab