Learn R Programming

jacobi (version 3.1.1)

wzeta: Weierstrass zeta function

Description

Evaluation of the Weierstrass zeta function.

Usage

wzeta(z, g = NULL, omega = NULL, tau = NULL)

Value

A complex number, vector or matrix.

Arguments

z

complex number, vector or matrix

g

the elliptic invariants, a vector of two complex numbers; only one of g, omega and tau must be given

omega

the half-periods, a vector of two complex numbers; only one of g, omega and tau must be given

tau

the half-periods ratio; supplying tau is equivalent to supply omega = c(1/2, tau/2)

Examples

Run this code
# Mirror symmetry property:
z <- 1 + 1i
g <- c(1i, 1+2i)
wzeta(Conj(z), Conj(g))
Conj(wzeta(z, g))

Run the code above in your browser using DataLab