powered by
Evaluation of the Weierstrass zeta function.
wzeta(z, g = NULL, omega = NULL, tau = NULL)
A complex number, vector or matrix.
complex number, vector or matrix
the elliptic invariants, a vector of two complex numbers; only one of g, omega and tau must be given
g
omega
tau
the half-periods, a vector of two complex numbers; only one of g, omega and tau must be given
the half-periods ratio; supplying tau is equivalent to supply omega = c(1/2, tau/2)
omega = c(1/2, tau/2)
# Mirror symmetry property: z <- 1 + 1i g <- c(1i, 1+2i) wzeta(Conj(z), Conj(g)) Conj(wzeta(z, g))
Run the code above in your browser using DataLab